@@ -603,7 +603,7 @@ static int exec_command( const char ** const ibufpp, const bool isglobal )
               if( fnp[0] == '!' )
                 { set_error_msg( "Invalid redirection" ); return ERR; }
               if( fnp[0] && !set_def_filename( fnp ) ) return ERR;
-              print_filename( def_filename, true ); putchar('\n');
+              print_escaped( def_filename, true ); putchar('\n');
               break;
     case 'g':
     case 'v':
@@ -843,7 +843,7 @@ int main_loop( const bool initial_error, const bool loose )
     set_warned( status == EMOD );		/* errors reset warned */
     if( warned() ) set_error_msg( "Warning: buffer modified" );
     if( !interactive() )
-      { if( verbose ) printf( "script, line %d: %s\n", linenum(), errmsg );
+      { if( verbose ) printf( "script, line %u: %s\n", linenum(), errmsg );
         return ( status == FATAL ) ? 1 : err_status; }
     if( status == FATAL )
       { if( verbose ) { printf( "%s\n", errmsg ); } return 1; }
